#!/usr/bin/python

import sys
import os
import argparse

import numpy as np

import MDAnalysis as mda
from MDAnalysis.analysis.hole import HOLE

#### INPUT PARAMETERS
parser = argparse.ArgumentParser(
        description='Performs HOLE analysis on a trajectory.')

parser.add_argument( "str_file", help="structure file [pdb, gro]")
parser.add_argument( "trj_file", help="trj file [xtc]")

parser.add_argument( "-b", "--begin", type=int, help="frame index to begin", default=None)
parser.add_argument( "-e", "--end", type=int, help="frame index to end", default=None)

parser.add_argument( "-d", "--dir", type=str, help="output directory", default=".")

args = parser.parse_args()

#----------------------------------------
try: os.makedirs(args.dir)
except: pass

TMP_PDB = os.path.join(args.dir, "tmp.pdb")
    
u = mda.Universe(args.str_file ,args.trj_file)
sel = u.select_atoms('all')

if args.begin:
    FRM_START = args.begin
else:
    FRM_START = 0

if args.end:
    FRM_END = args.end+1
else:
    FRM_END = len(u.trajectory)

for fr in u.trajectory[FRM_START:FRM_END]:
    sel.write(TMP_PDB)
    
    H = HOLE(TMP_PDB,
             executable="/opt/hole2/exe/hole",
             logfile=os.path.join(args.dir,"hole_%i.out" % fr.frame),
             sphpdb=os.path.join(args.dir, "hole_%i.sph" % fr.frame),
             radius="/opt/hole2/rad/simple.rad")
    
    H.run()
    H.collect()
    try:
        r = H.profiles[0]
    except KeyError: continue
    
    a = np.array((r.rxncoord, r.radius))
    np.save(os.path.join(args.dir, "hole_%i.npy" % fr.frame), a)

